C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      subroutine chk_input(
     &                      max_pixel,
     &                      nscans,
     &                      lines_in_edge,
     &                      beg_lin,
     &                      nlins,
     &                      beg_ele,
     &                      neles,
     &                      maxele,
     &                      maxlin,
     &                      max_count,
     &                      max5km_lin,
     &                      max5km_ele 
     &                    )

      implicit none
      save

c --- Include files Needed for time conversion
      include 'global.inc'

c --- Common Block for debugging code
      integer	     debug
      integer	     h_output
      common / bug / debug, h_output

c-------------------------------------------------------------------
C!F77
C
C!DESCRIPTION:
C    Routine for checking consistency of input parameters.
C
c!Input Parameters:
C max_pixel     Maximum number of pixels per scan in granule
c nscans        Number of scans for this granule
c lines_in_edge Number of lines outside of processing region
c beg_lin    Beginning line number to process
c nlins      Number of lines to process
c beg_ele    Beginning element number to process
c neles      Number of elements to process
c
c
c!Output Parameters:
c maxele        Maximum number of elements possible in granule
c maxlin        Number of lines in this granule
c max_count     Number of lines + lines_in_edge of granule
c max5km_lin    Max number of lines in 5km array
c max5km_ele    Max number of elements in 5km array
c
c!Revision History:
c
c!Team-unique Header:
c
c!References and Credits:
c See Cloud Mask ATBD-MOD-06.
c Externals:  error messaging routine   -  message.f
c
c!END
c-------------------------------------------------------------------

c --- parameters
      integer 		maxlin
      integer 		maxele
      integer 		max_count
      integer 		nscans
      integer 		max_pixel
      integer 		lines_in_edge
      integer		max5km_lin
      integer		max5km_ele
      integer		beg_lin
      integer		nlins
      integer		beg_ele
      integer		neles

c --- internal variables 
      character*(512) 	btime_string
      character*(512) 	etime_string
      integer		itest
      integer		ibls
      integer		ibes
      double precision  Start1
      double precision  Start2
      double precision  Stop1
      double precision  Stop2


c --- initialize variables
      itest = -1
      btime_string = '    '
      etime_string = '    '

      start1 = 0.0d0
      start2 = 0.0d0
      stop1 = 0.0d0
      stop2 = 0.0d0

c --- maxlin is number of lines to process
      maxlin = nscans * SCANS_CUBE

c --- 5 km variables are for reduced resolution swath files
      max5km_lin = maxlin / 5
      max5km_ele = max_pixel / 5
 
c --- max_count = number of lines + edge lines
c     maxele is taken right from granule metadata
      if( beg_lin.eq.0 .and. beg_ele.eq.0 ) then
          beg_lin = 1
          beg_ele = 1
          max_count = maxlin + lines_in_edge
          maxele = max_pixel

      else
          ibls = beg_lin
          beg_lin = ibls - ((NLCNTX-1) / 2)
          ibes = beg_ele
          beg_ele = ibes - ((NECNTX-1) / 2)
          max_count = beg_lin + ((NLCNTX-1) + (nlins))
          maxele    = beg_ele + ((NECNTX-1) + (neles - 1))

          if( max_count.gt.maxlin .or. maxele.gt.max_pixel) then
            call message(
     &                  'chk_input',
     &                  'FAILED: Number of lines/elements was .gt. max',
     &                  0, 2 )
          endif

      endif

      if( maxlin.le.0 .or. 
     &    maxele.le.0 .or. 
     &    beg_lin.le.0 .or.
     &    beg_ele .le. 0   
     &) then
        call message( 'chk_input',
     &                'FAILED: Number of lines/elements was .le. 0.',
     &                0, 2 )
      endif

c --- debug
      if(debug .gt. 0) then
         write(h_output,fmt=
     &   '(1x,''Debug  lines  '',i10, '' and elements '',i10,/)')
     &   maxlin, maxele
      endif

      return
      end
