C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      subroutine file_open( 
     &                      filename,
     &                      l1b_1km_neles,
     &                      eco_1km_lun,
     &                      eco_10min_lun,
     &                      l1b_250m_lun,
     &                      l1b_1km_lun,
     &                      geo_1km_lun,
     &                      scan_1km_lun,
     &                      anc_met_lun,
     &                      anc_nisen_lun,
     &                      anc_nises_lun,
     &                      anc_icec_lun,
     &                      anc_ozone_lun,
     &                      anc_sst_lun,
     &                      anc_thresholds_lun,
     &                      mask_lun,
     &                      hdr_lun,
     &                      qahdr_lun,
     &                      qa_lun,
     &                      debug_lun,
     &                      l1b_250m_open
     &                    )
      implicit none
      save

      include 'cloudmask.inc'

C-----------------------------------------------------------------------
C!F77
C
C!DESCRIPTION:
c Program which will open files and return unit numbers for 
c all open files used in the main program. 
C
C!INPUT PARAMETERS:    None.
C
C!OUTPUT PARAMETERS:
C
C   filename           Configuration file name
C   eco_1km_lun        LUN for open 1km ecosystem file
C   eco_10min_lun      LUN for open 10min ecosystem file
C   l1b_1km_lun        LUN for open 1km L1B data file
C   l1b_250m_lun       LUN for open 250m L1B data file
C   geo_1km_lun        LUN for open geo file
C   anc_met_lun        LUN for open land sea mask file
C   anc_nisen_lun      LUN for open NH ice/snow mask file
C   anc_nises_lun      LUN for open SH ice/snow mask file
C   anc_seaice_lun     LUN for open sea ice mask file
C   anc_thresholds_lun LUN for open sea ice mask file
C   mask_lun           LUN for open cloud mask file
C   hdr_lun            LUN for output file header
C   qahdr_lun          LUN for open cloud mask file
C   qahdr_lun          LUN for qa output file header
C   debug_lun          LUN for open debug messages file
c   l1b_250m_open      Logical flag set to true if 250 data is used
C
C!REVISION HISTORY:
c
C!TEAM-UNIQUE HEADER:
C
C!REFERENCES AND CREDITS
C
C EXTERNALS:
C
C       NAMED CONSTANTS:
C
C       FUNCTIONS AND SUBROUTINES:
C               hdrgetkeystr.f
c               message.f
C
C!END-------------------------------------------------------------------

c --- constants
      character*32 		FUNCTION
      parameter 		(FUNCTION = 'file_open')

c --- input argument
      character*(*)             filename

c --- parameters
      integer			l1b_1km_neles
      integer			eco_1km_lun
      integer			eco_10min_lun
      integer			l1b_1km_lun
      integer			l1b_250m_lun
      integer			geo_1km_lun
      integer			scan_1km_lun
      integer			anc_met_lun
      integer			anc_nisen_lun
      integer			anc_nises_lun
      integer			anc_icec_lun
      integer			anc_sst_lun
      integer			anc_ozone_lun
      integer			anc_thresholds_lun
      integer			mask_lun
      integer			qa_lun
      integer			hdr_lun
      integer			qahdr_lun
      integer			debug_lun
      logical 			l1b_250m_open

c --- external functions
      integer			hdrgetkeystr

c --- internal variables
      character*12 		req
      character*80		keyname
      character*512		file
      integer			len_file
      integer			keyindex
      integer			status
      integer			io_err
      integer			level
      integer			len
      logical			eco_1km_open
      logical			eco_10min_open
      logical			l1b_1km_open
      logical			geo_1km_open
      logical			scan_1km_open
      logical			anc_met_open
      logical			anc_nisen_open
      logical			anc_nises_open
      logical			anc_icec_open
      logical			anc_sst_open
      logical			anc_ozone_open
      logical			anc_thresholds_open
      logical			mask_open
      logical			qa_open
      logical			debug_open
      logical			remove_all

c --- Common block used for writing debug output statements
      integer			debug
      integer			h_output
      common / bug / debug, h_output


c --- initialize open flag
      eco_1km_open         = .FALSE.
      eco_10min_open       = .FALSE.
      l1b_250m_open        = .FALSE.
      l1b_1km_open         = .FALSE.
      geo_1km_open         = .FALSE.
      scan_1km_open        = .FALSE.
      anc_met_open     	   = .FALSE.
      anc_nisen_open	   = .FALSE.
      anc_nises_open	   = .FALSE.
      anc_icec_open	   = .FALSE.
      anc_sst_open	   = .FALSE.
      anc_ozone_open	   = .FALSE.
      mask_open	       	   = .FALSE.
      qa_open	       	   = .FALSE.
      debug_open           = .FALSE.
      remove_all	   = .FALSE.

c --- initialize the lun
      eco_1km_lun	   = -1
      eco_10min_lun	   = -1
      l1b_1km_lun	   = -1
      l1b_250m_lun	   = -1
      geo_1km_lun	   = -1
      scan_1km_lun	   = -1
      anc_met_lun	   = -1
      anc_nisen_lun	   = -1
      anc_nises_lun	   = -1
      anc_icec_lun	   = -1
      anc_sst_lun	   = -1
      anc_ozone_lun	   = -1
      anc_thresholds_lun   = -1
      mask_lun	           = -1
      qa_lun	           = -1
      hdr_lun	           = -1
      qahdr_lun	           = -1
      debug_lun	           = -1


C GLOBAL 1KM ECOSYSTEM FILE

c --- get the file requirement
      keyname = 'ECO_1KM_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
c     Make this one mandatory. YOU DON'T WANT TO RUN WITHOUT IT.
      level = 3

c --- get file access information 
      keyname = 'ECO_1KM_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, file )

c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED - Read of 1km Ecosystem file name. ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file,
     &         UNIT=ECO_1KM_UNIT,
     &         STATUS=ECO_1KM_STATUS,
     &         FORM=ECO_1KM_FORM,
     &         ACCESS=ECO_1KM_ACCESS,
     &         RECL=ECO_1KM_RECL,
     &         IOSTAT=io_err, 
     &         ERR=9001 
     &       ) 

         call message(
     &                 '--',
     &                'Using Ecosystem file: '// file ,
     &                 0, 4
     &               )

         eco_1km_lun = ECO_1KM_UNIT
         eco_1km_open = .TRUE.
         goto 100

c ------ Failed to open file (non-fatial)  
9001     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED - to open 1km ecosystem file.',
     &                 0, level 
     &               )


      endif
100   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  ecosystem 1km file: ',file(1:len_file)
      endif

      
C 250M Level 1B MODIS DATA FILES

c --- get the file requirement
      keyname = 'L1B_250M_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 2
      if( req(1:3).eq.'MAN' ) level = 3

c --- get file access information 
      keyname = 'L1B_250M_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, file )

c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of 250m file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file,
     &         UNIT=L1B_250M_UNIT,
     &         FORM=L1B_250M_FORM,
     &         ACCESS=L1B_250M_ACCESS,
     &         STATUS=L1B_250M_STATUS,
     &         RECL=l1b_1km_neles*16,
     &         IOSTAT=io_err, 
     &         ERR=9004
     &       ) 

         call message(
     &                 '--',
     &                'Using 250m L1B file: '// file ,
     &                 0, 4
     &               )


         l1b_250m_lun = L1B_250M_UNIT
         l1b_250m_open = .TRUE.
         goto 130

c ------ Failed to open 
9004     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Open 250m L1B file. ' ,
     &                 0, level 
     &               )

      endif

130   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  L1B 250m file: ',file(1:len_file)
      endif
      


C 1KM Level 1B MODIS DATA FILES

c --- get the file requirement
      keyname = 'L1B_1KM_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 2
      if( req(1:3).eq.'MAN' ) level = 3

c --- get file access information 
      keyname = 'L1B_1KM_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, file )

c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of 1km file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file,
     &         UNIT=L1B_1KM_UNIT,
     &         FORM=L1B_1KM_FORM,
     &         ACCESS=L1B_1KM_ACCESS,
     &         STATUS=L1B_1KM_STATUS,
     &         RECL=l1b_1km_neles*4,
     &         IOSTAT=io_err, 
     &         ERR=9005
     &       ) 

         call message(
     &                 '--',
     &                'Using 1km L1B file: '// file ,
     &                 0, 4
     &               )

         l1b_1km_lun = L1B_1KM_UNIT
         l1b_1km_open = .TRUE.
         goto 140

c ------ Failed to open 
9005     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Open 1km L1B file. ', 
     &                 0, level 
     &               )

      endif
140   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  L1B 1km file: ',file(1:len_file)
      endif
              


C GEOLOCATION FILES: LATITUDE, LONGITUDE, HEIGHT, ...

c --- get the file requirement
      keyname = 'GEO_1KM_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 2
      if( req(1:3).eq.'MAN' ) level = 3

c --- get file access information 
      keyname = 'GEO_1KM_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, file )

c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of Geo file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file,
     &         UNIT=GEO_1KM_UNIT,
     &         STATUS=GEO_1KM_STATUS,
     &         FORM=GEO_1KM_FORM,
     &         ACCESS=GEO_1KM_ACCESS,
     &         RECL=l1b_1km_neles*4,
     &         IOSTAT=io_err, 
     &         ERR=9006
     &       ) 

         call message(
     &                 '--',
     &                'Using 1km GEO file: '// file ,
     &                 0, 4
     &               )

         geo_1km_lun = GEO_1KM_UNIT
         geo_1km_open = .TRUE.
         goto 150

c ------ Failed to open 
9006     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Open GEO file. ',
     &                 0, level 
     &               )

      endif
150   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  GEO file: ',file(1:len_file)
      endif
              


C SCAN METADATA FILE: TYPE, MIRROR SIDE

c --- get the file requirement
      keyname = 'SCAN_1KM_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 2
      if( req(1:3).eq.'MAN' ) level = 3

c --- get file access information 
      keyname = 'SCAN_1KM_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, file )

c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of Scan Metadata file info . ',
     &                 0, level 
     &               )

      else

c ------ issue the OPEN request
         OPEN( 
     &         FILE=file,
     &         UNIT=SCAN_1KM_UNIT,
     &         STATUS=SCAN_1KM_STATUS,
     &         FORM=SCAN_1KM_FORM,
     &         ACCESS=SCAN_1KM_ACCESS,
     &         RECL=SCAN_1KM_RECL,
     &         IOSTAT=io_err, 
     &         ERR=9007
     &       ) 

         call message(
     &                 '--',
     &                'Using Meta file: '// file ,
     &                 0, 4
     &               )

         scan_1km_lun = SCAN_1KM_UNIT
         scan_1km_open = .TRUE.
         goto 160

c ------ Failed to open 
9007     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Open Scan Metadata file. ',
     &                 0, level 
     &               )

      endif
160   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  Scan Metadata file: ',file(1:len_file)
      endif
      
C ANCILLARY FILES: NORTHERN NISE

c --- get the file requirement
      keyname = 'ANC_NISEN_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 2
      if( req(1:3).eq.'MAN' ) level = 3

c --- get file access information 
      keyname = 'ANC_NISEN_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, file )
      call strcompress( file, remove_all, len ) 

c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of Northern NISE file info. ',
     &                 0, level 
     &               )

      else
 
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file(1:len),
     &         UNIT=ANC_NISEN_UNIT,
     &         STATUS=ANC_NISEN_STATUS,
     &         FORM=ANC_NISEN_FORM,
     &         ACCESS=ANC_NISEN_ACCESS,
     &         RECL=ANC_NISEN_RECL,
     &         IOSTAT=io_err, 
     &         ERR=9010 
     &       ) 

         call message(
     &                 '--',
     &                'Using NH NISE file: '// file ,
     &                 0, 4
     &               )

         anc_nisen_lun = ANC_NISEN_UNIT
         anc_nisen_open = .TRUE.
         goto 190

c ------ Failed to open 
9010     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Open Northern NISE file. ',
     &                 0, level 
     &               )

      endif
190   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  NH Nise file: ',file(1:len_file)
      endif
      


C ANCILLARY FILES: SOUTHERN NISE

c --- get the file requirement
      keyname = 'ANC_NISES_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 2
      if( req(1:3).eq.'MAN' ) level = 3

c --- get file access information 
      keyname = 'ANC_NISES_NAME' 
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, file ) 
      call strcompress( file, remove_all, len ) 

c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of Southern NISE file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file(1:len),
     &         UNIT=ANC_NISES_UNIT,
     &         STATUS=ANC_NISES_STATUS,
     &         FORM=ANC_NISES_FORM,
     &         ACCESS=ANC_NISES_ACCESS,
     &         RECL=ANC_NISES_RECL,
     &         IOSTAT=io_err, 
     &         ERR=9011
     &       ) 

         call message(
     &                 '--',
     &                'Using SH NISE file: '// file ,
     &                 0, 4
     &               )

         anc_nises_lun = ANC_NISES_UNIT
         anc_nises_open = .TRUE.
         goto 200

c ------ Failed to open 
9011     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Open Sounthern NISE file. ',
     &                 0, level 
     &               )

      endif
200   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  SH Nise file: ',file(1:len_file)
      endif

      


C ANCILLARY FILES: ICE

c --- get the file requirement
      keyname = 'ANC_ICEC_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 2
      if( req(1:3).eq.'MAN' ) level = 3

c --- get file access information 
      keyname = 'ANC_ICEC_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, file )
      call strcompress( file, remove_all, len ) 

c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of Ice file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file(1:len),
     &         UNIT= ANC_ICEC_UNIT,
     &         STATUS= ANC_ICEC_STATUS,
     &         FORM= ANC_ICEC_FORM,
     &         ACCESS= ANC_ICEC_ACCESS,
     &         RECL= ANC_ICEC_RECL,
     &         IOSTAT=io_err, 
     &         ERR= 9012
     &       ) 

         call message(
     &                 '--',
     &                'Using SSMI SeaIce file: '// file ,
     &                 0, 4
     &               )

         anc_icec_lun = ANC_ICEC_UNIT
         anc_icec_open = .TRUE.
         goto 210

c ------ Failed to open 
9012     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Open Ice file. ',
     &                 0, level 
     &               )

      endif
210   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  Ice file: ',file(1:len_file)
      endif

      

C ANCILLARY FILES: THRESHOLDS

c --- get the file requirement
      keyname = 'ANC_THRESHOLD_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 2
      if( req(1:3).eq.'MAN' ) level = 3

c --- get file access information 
      keyname = 'ANC_THRESHOLD_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, file )
      call strcompress( file, remove_all, len ) 

c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of Thresholds file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file(1:len),
     &         UNIT= ANC_THRESHOLD_UNIT,
     &         STATUS= ANC_THRESHOLD_STATUS,
     &         FORM= ANC_THRESHOLD_FORM,
     &         ACCESS= ANC_THRESHOLD_ACCESS,
     &         IOSTAT=io_err, 
     &         ERR= 9013
     &       ) 

         call message(
     &                 '--',
     &                'Using Threshold file: '// file ,
     &                 0, 4
     &               )

         anc_thresholds_lun = ANC_THRESHOLD_UNIT
         anc_thresholds_open = .TRUE.
         goto 220

c ------ Failed to open 
9013     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Open Thresholds file. ',
     &                 0, level 
     &               )

      endif
220   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  Thresholds file: ',file(1:len_file)
      endif
      


C OUTPUT FILES: CLOUD MASK 

c --- get the file requirement
      keyname = 'MOD35_MASK_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 2
      if( req(1:3).eq.'MAN' ) level = 3

c --- get file access information 
      keyname = 'MOD35_MASK_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex,file )
      call strcompress( file, remove_all, len ) 


c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of Cloud Mask file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file(1:len),
     &         UNIT=MOD35_MASK_UNIT,
     &         STATUS=MOD35_MASK_STATUS,
     &         ACCESS=MOD35_MASK_ACCESS,
     &         RECL=l1b_1km_neles,
     &         IOSTAT=io_err, 
     &         ERR=9017
     &       ) 

         call message(
     &                 '--',
     &                'Creating Cloud Mask Ouput file: '// file ,
     &                 0, 4
     &               )

         mask_lun = MOD35_MASK_UNIT
         mask_open = .TRUE.
         goto 260

c ------ Failed to open 
9017     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Open Cloud Mask file. ',
     &                 0, level 
     &               )

      endif
260   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  Cloud Mask file: ',file(1:len_file)
      endif
      
C OUTPUT FILES: CLOUD MASK HEADER FILE

c --- get the file requirement
      keyname = 'MOD35_MASK_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 2
      if( req(1:3).eq.'MAN' ) level = 3

c --- get file access information 
      keyname = 'MOD35_HDR_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex,file )
      call strcompress( file, remove_all, len ) 


c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of Cloud Mask HEADER file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file(1:len),
     &         UNIT=MOD35_HDR_UNIT,
     &         STATUS=MOD35_HDR_STATUS,
     &         ACCESS=MOD35_HDR_ACCESS,
     &         IOSTAT=io_err, 
     &         ERR=9018
     &       ) 

         hdr_lun = MOD35_HDR_UNIT
         goto 261

c ------ Failed to open 
9018     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Open Cloud Mask Header file. ',
     &                 0, level 
     &               )

      endif
261   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  Cloud Mask Header file: ',file(1:len_file)
      endif


C OUTPUT FILES: CLOUD MASK QUALITY CONTROL 

c --- get the file requirement
      keyname = 'MOD35_QA_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 2
      if( req(1:3).eq.'MAN' ) level = 3

c --- get file access information 
      keyname = 'MOD35_QA_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex,file )
      call strcompress( file, remove_all, len ) 


c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of Quality Control file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file(1:len),
     &         UNIT=MOD35_QA_UNIT,
     &         STATUS=MOD35_QA_STATUS,
     &         ACCESS=MOD35_QA_ACCESS,
     &         RECL=l1b_1km_neles,
     &         IOSTAT=io_err, 
     &         ERR=9019
     &       ) 

         call message(
     &                 '--',
     &                'Creating Cloud Mask QA Ouput file: '// file ,
     &                 0, 4
     &               )

         qa_lun = MOD35_QA_UNIT
         qa_open = .TRUE.
         goto 262

c ------ Failed to open 
9019     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Open Quality Control file. ',
     &                 0, level 
     &               )

      endif
262   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  Quality Control file: ',file(1:len_file)
      endif


C OUTPUT FILES: CLOUD MASK QUALITY CONTROL HEADER FILE

c --- get the file requirement
      keyname = 'MOD35_QA_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 2
      if( req(1:3).eq.'MAN' ) level = 3

c --- get file access information 
      keyname = 'MOD35_QAHDR_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex,file )
      call strcompress( file, remove_all, len ) 


c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of QC Header file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file(1:len),
     &         UNIT=MOD35_QAHDR_UNIT,
     &         STATUS=MOD35_QAHDR_STATUS,
     &         ACCESS=MOD35_QAHDR_ACCESS,
     &         IOSTAT=io_err, 
     &         ERR=9020
     &       ) 

         qahdr_lun = MOD35_QAHDR_UNIT
         goto 263

c ------ Failed to open 
9020     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Open Quality Control Header file. ',
     &                 0, level 
     &               )

      endif
263   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  Quality Control Header file: ',file(1:len_file)
      endif


C RUNTIME DEBUG FILE

c --- get the file requirement
      keyname = 'DEBUG_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 2
      if( req(1:3).eq.'MAN' ) level = 3

c --- get file access information 
      keyname = 'DEBUG_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, file )
      call strcompress( file, remove_all, len ) 

c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of RunTime Debug file info. ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file(1:len),
     &         UNIT=DEBUG_UNIT,
     &         STATUS=DEBUG_STATUS,
     &         FORM=DEBUG_FORM,
     &         ACCESS=DEBUG_ACCESS,
     &         IOSTAT=io_err, 
     &         ERR=9021 
     &       ) 

         debug_lun = DEBUG_UNIT
         debug_open = .TRUE.
         goto 270

c ------ Failed to open 
9021     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Open RunTime Debug file. ',
     &                 0, level 
     &               )

      endif
270   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  Debug file: ',file(1:len_file)
      endif

      return
      end
