C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      subroutine get_pn_thresholds(bt_11,locut,hicut,midpt,power)

      implicit none
      save

c---------------------------------------------------------------------
C!F77
c
c!Description:
c     Routine for setting cloud test thresholds for 11 minus 3.9 um
c     test in polar night conditions.
c
c!Input parameters:
c bt_11         11 um brightness temperature for current pixel
c
c!Output Parameters:
c locut         Zero confidence value of clear sky confidence interval
c hicut         1.0 confidence value of clear sky confidence interval
c midpt         0.5 confidence value of clear sky confidence interval
c power         Power of clear sky confidence curve
c
c!Revision History:
c Original version - 03/07/2002     
c Rich Frey              MODIS Science Group at UW-Madison
c
c!Team-unique Header:
c
c!References and Credits:
c See Cloud Mask ATBD-MOD-35.
c
c!END
c---------------------------------------------------------------------

c     Include files.
      include 'PolarNite_snow_thr.inc'

c     Scalar arguments.
      real bt_11,locut,hicut,midpt,power

c     Local scalars.
      real lo_tmp,hi_tmp,lo_tmp_thr,hi_tmp_thr,a,conf_range

c     Compute clear sky confidence interval boundaries and mid-point.

      if(bt_11 .lt. bt_11_bounds(1)) then

        hicut = pn_11_4l(3)
        locut = pn_11_4l(1)
        midpt = pn_11_4l(2)
        power = pn_11_4l(4)

      else if(bt_11 .gt. bt_11_bounds(2)) then

        hicut = pn_11_4h(3)
        locut = pn_11_4h(1)
        midpt = pn_11_4h(2)
        power = pn_11_4h(4)

      else

        lo_tmp = bt_11_bounds(1)
        hi_tmp = bt_11_bounds(2)
        lo_tmp_thr = pn_11_4m(1)
        hi_tmp_thr = pn_11_4m(2)
        power = pn_11_4m(4)
        conf_range = pn_11_4m(3)

        a = (bt_11 - lo_tmp) / (hi_tmp - lo_tmp)
        midpt = lo_tmp_thr + a*(hi_tmp_thr - lo_tmp_thr)
        hicut = midpt - conf_range
        locut = midpt + conf_range
       
      end if

      return
      end
