C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      subroutine get_regstd(indat,kele,maxele,line_edge,klin,rgdata,   
     +                      sigma_31)

      implicit none
      save

c---------------------------------------------------------------------
c!F77
c
c!DESCRIPTION:
c     Computes standard deviation of (center) pixel of interest and the     
c     surrounding eight pixel values for MODIS channel 31.   
c
c
c!Input parameters:
c indat         Array containing nlcltx number of lines of
c               reflectance or BT values for each channel
c kele          First element pixel in the region (context)
c maxele        Maximum number of pixels in a scan
c line_edge     Logical variable indicating first or last line of
c               data in a granule
c klin          Counter indicating number of lines processed
c
c!Output Parameters:
c rgdata        Array containing current pixel and surrounding pixel
c               reflectance and brightness temperature information
c sigma_31      Standard deviation of MODIS channel 31 brightness
c               temperatures
c
c!Revision History:
c
c!Team-unique Header:
c
c!References and Credits:
c See Cloud Mask ATBD-MOD-06.
c
c!END
c---------------------------------------------------------------------------

      INCLUDE 'global.inc'

c     scalar arguments
      integer kele,maxele,klin
      real sigma_31
      logical line_edge

c     array arguments
      real rgdata(nlcntx,necntx,var_band),
     +     indat(npixel,nlcntx,inband)

c     local scalars
      integer imv,ide,i,j,k,nl
      double precision n,num,den,sqsum,sumsq,sum,tbb,sig

c     local arrays
      integer band(var_band)
      real sigma(var_band)

c     bands for which to compute standard deviation
      data band /1,31/

c     Initialize variables.

      imv = 0
      ide = 0
      do 10 i = 1 , nlcntx
        do 20 j = 1 , necntx
          do 30 k = 1 , var_band
            rgdata(i,j,k) = 0.0
   30     continue
   20   continue
   10 continue

c ... put pixel data into context data array.

      imv = ((necntx-1)/2) + 1

      if(line_edge .and. klin .eq. 1) then
        nl = 1
      else if(line_edge .and. klin .gt. 1) then
        nl = 2
      else
        nl = nlcntx
      end if

      do 100 i = 1,nl
        do 200 j = 1,necntx
          ide = kele + (j-imv)
          do 300 k = 1,var_band
            if(ide .gt. 0 .and. ide .le. maxele) then
              if (indat(ide,i,band(k)).gt.0.0 .and.
     +              indat(ide,i,band(k)).lt.1000000.0) then
                rgdata(i,j,k) = indat(ide,i,band(k))
              else
                rgdata(i,j,k) = bad_data
              end if
            else
              rgdata(i,j,k) = bad_data
            end if
  300     continue
  200   continue
  100 continue

c     Get standard deviation central pixel.

      do 600 k = 1,var_band

        n = 0.d0
        sum = 0.d0
        sumsq = 0.d0
        do 400 i = 1,nl
          do 500 j = 1,necntx
	    tbb = dble(rgdata(i,j,k))
	    if(abs(tbb-bad_data) .gt. 0.1) then
	       n = n + 1.d0
	       sum = sum + tbb          
	       sumsq = sumsq + (tbb * tbb)
            end if
 500      continue
 400    continue 

        if(n .gt. 1.d0) then
          sqsum = sum * sum
          num = (n * sumsq) - sqsum
          den = n * (n-1)
          sig = dsqrt(num / den)
        else if(n .eq. 1.d0) then
          sig = 0.d0
        else
          sig = dble(bad_data)
        end if 
        sigma(k) = sngl(sig)

 600  continue

      sigma_31 = sigma(2)

      return
      end
