C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      subroutine noncld_obs_chk(pxldat,smoke,qa_bits,testbits,
     +                          confdnc)

      implicit none
      save

C!F77 ************************************************************
c!Description:
c ... Routine which checks for the presence of a non-cloud obstruction.
c ... Currently checks for smoke.
c
c!Input Parameters:
c pxldat        Array containing reflectance or brightness temperatures
c               for all bands for a single pixel
c
c!Output Parameters:
c smoke         logical variable indicating shadow is present if .true.
c qa_bits       Byte array containing qa bits results
c
c!Revision History:
c
c!Team-unique Header:
c
c    This software is developed by the MODIS Science Data Support Team
c    for the National Aeronautics and Space Administration,
c    Goddard Space Flight Center, under contract NAS5-32373.
c
c!References and Credits:
c See Cloud Mask ATBD-MOD-06.
c
c!Design Notes:
c
c!END****************************************************************
c
      include 'global.inc'
      include 'noncld_obs_chk.inc'

c ... scalar arguments ..
      logical smoke
      real confdnc

c ... array arguments
      real pxldat(inband)
      byte qa_bits(10),testbits(6)

c ... local scalars ..
      logical fire
      real masv21,masv66,masir3,masir11,tdif,coef,masir12,tdiff,
     +     masv55
      integer debug,h_output

C ... Common statement for debug purposes
      common / bug / debug, h_output

c     Routine which checks for the possible presence of smoke.

c     Initializations.
      fire = .false.

      masv66 = pxldat(1)
      masv55 = pxldat(4)
      masv21 = pxldat(7)
      masir3 = pxldat(20)
      masir11 = pxldat(31)
      masir12 = pxldat(32)

c ... debug statement ............................................
      if (debug .gt. 0) then
        write(h_output,'(10x/,''Within nco bit testing routine '',/)')
      endif
c ................................................................

      if (nint(masv66) .ne. nint(bad_data)
     +                 .and.
     +    nint(masv21) .ne. nint(bad_data)
     +                 .and.
     +    nint(masir3) .ne. nint(bad_data)  
     +                 .and.
     +    nint(masir11)  .ne. nint(bad_data)) then

        tdif = masir3 - masir11
        coef = 7.0 + (masv21*100.0 / 2.0)

c       Set bit to say that we did attempt nco smoke test
        call set_qa_bit(qa_bits,8)

c       First, check for fires (hot spots).
        if (masir3 .gt. nc_bt37(1) .and. tdif .gt. nc37_11(1)) then
            fire = .true.
        end if 

c       Test for thick smoke or fire. 
        if(masv21*100.  .lt. nc21(1)) then
          if((masv66*100. .gt. coef) .or. fire) then
            smoke = .true.
          end if
        end if

c ...   debug statement ............................................
        if (debug .gt. 0) then
          write(h_output,'(10x,'' NCO test '',/,6f8.2,2l4/)')
     *    masv21,masv66,tdif,masir3,masir11,coef,fire,smoke
        endif
c ..................................................................

      endif

c ..................................................................

c     Perform dust test.
      if (nint(masir11) .ne. nint(bad_data)
     +                 .and.
     +    nint(masir12) .ne. nint(bad_data)) then

        if(confdnc .gt. 0.67) then

c         Set bit to say that we attempted the nco dust test
          call set_qa_bit(qa_bits,28)

          tdiff = masir11 - masir12

          if(tdiff .lt. nc11_12(1)) then
            call clear_bit(testbits,28)
          end if

        end if

      end if

c ..................................................................

c ....debug statement ............................................
      if (debug .gt. 0) then
        if (smoke) then
          write(h_output,'(10x,'' Smoke found ''/)')
        else
          write(h_output,'(10x,'' Smoke not found ''/)')
        endif
      endif
c ................................................................

      return
      end
