C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center,
C  University C  of Wisconsin-Madison, Madison WI.
C
C  This program is free software; you can redistribute it
C  and/or modify it under the terms of the GNU General
C  Public License as published by the Free Software Foundation;
C  either version 2 of the License, or (at your option) any
C  later version.
C
C  This program is distributed in the hope that it will be
C  useful, but WITHOUT ANY WARRANTY; without even the implied
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public
C  License along with this program; if not, write to the Free
C  Software Foundation, Inc., 59 Temple Place, Suite 330,
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      subroutine set_unused_bits(testbits)

      implicit none
      save

c-------------------------------------------------------------------
C!F77 
c
c!Description:
c     Set (as yet) unused bits. 
c     These bits are:
c          Spare bit (bit 23)
c          The cloud adjancency bit (bit 12)
c          The temporal consistency test (bit 24)
c          Spare bits (30-31)
c
c!Input parameters:
c testbits      6 cell byte array containing cloud mask bit results
c
c!Output Parameters:
c None.
c
c!Revision History:
c
c!Team-unique Header:
c
c!References and Credits:
c See Cloud Mask ATBD-MOD-06.
c
c!END
c-------------------------------------------------------------------

c ... arguments ..
      byte testbits(6)

c ... local scalars ..
      integer debug,h_output,i

c ... external subroutines
      external set_bit

c ... Common statement for debug purposes
      common / bug / debug, h_output


c ... debug statement ............................................
      if (debug .gt. 1) then
        write(h_output,'(10x/,''Within unused bits routine '',/)')
      endif
c ................................................................

c     Set temporal consistency test bit
      call set_bit(testbits,24)

c     Set cloud adjancency bit (a post-launch product)
      call set_bit(testbits,12) 

c     Set spare bits
      do i = 29 , 31
        call set_bit(testbits,i)
      enddo

      return
      end
